Helpers to manipulate EQL.
Helpers to manipulate EQL.
Shape descriptor is a format to describe data. This format optimizes for fast detection of value present given a shape and a value path.
This namespace contains functions to operate on maps in the shape descriptor format.
Shape descriptor is a format to describe data. This format optimizes for fast detection of value present given a shape and a value path. This namespace contains functions to operate on maps in the shape descriptor format.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |